﻿using ProjectPublishing.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Unity;

namespace ProjectPublishing.Forms
{
    public partial class FormPrintingHouses : Form
    {
        private readonly IUnityContainer _container;
        private readonly IPrintingHouseRepository _printingHouseRepository;
        public FormPrintingHouses(IUnityContainer container, IPrintingHouseRepository printingHouseRepository)
        {
            InitializeComponent();
            _container = container ?? throw new ArgumentException(nameof(container));
            _printingHouseRepository = printingHouseRepository ?? throw new ArgumentException(nameof(printingHouseRepository));
        }

        private void buttonAdd_Click(object sender, EventArgs e)
        {
            try
            {
                _container.Resolve<FormPrintingHouse>().ShowDialog();
                loadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при добавлении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonEdit_Click(object sender, EventArgs e)
        {
            if (!tryGetIDFromRow(out var findId))
            {
                return;
            }
            try
            {
                var form = _container.Resolve<FormPrintingHouse>();
                form.Id = findId;
                form.ShowDialog();
                loadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при изменении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonRemove_Click(object sender, EventArgs e)
        {
            if (!tryGetIDFromRow(out var findId))
            {
                return;
            }
            if (MessageBox.Show("Удалить запись?", "Удаление", MessageBoxButtons.YesNo) != DialogResult.Yes)
            {
                return;
            }

            try
            {
                _printingHouseRepository.DeletePrintingHouse(findId);
                loadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при удалении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void FormPrintingHouses_Load(object sender, EventArgs e)
        {
            try
            {
                loadList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при загрузке", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void loadList() => dataGridView.DataSource = _printingHouseRepository.ReadPrintingHouses();

        private bool tryGetIDFromRow(out int id)
        {
            id = 0;
            if (dataGridView.SelectedRows.Count < 1)
            {
                MessageBox.Show("Нет выбранной записи", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return false;
            }
            id = Convert.ToInt32(dataGridView.SelectedRows[0].Cells["Id"].Value);
            return true;
        }
    }
}
